@@ -1,7 +1,3 @@
-# flake8: noqa: F401
-
-from testcase.app.app_constants import constants
-
 """
 The purpose of this simple test app is to compute Surface MSE
 every 30 seconds of wits stream records. Note that this parameter
