@@ -1,17 +1,8 @@
-import os
-
-import rollbar
-
 from testcase.app.drilling_efficiency_app import DrillingEfficiency
-
-rollbar_token = os.getenv("ROLLBAR_TOKEN")
-env = os.getenv("ENVIRONMENT", os.getenv("APP_ENV"))
-enabled = bool(rollbar_token)
-
-rollbar.init(rollbar_token, env, handler='blocking', enabled=enabled)
+from worker.framework.timeout_handler import timeout_track
 
 
-@rollbar.lambda_function
+@timeout_track(default_timeout=30)
 def lambda_handler(event, context):
     """
     This function is the main entry point of the AWS Lambda function
@@ -19,7 +10,7 @@ def lambda_handler(event, context):
     :param context: AWS Context
     :return:
     """
-    app = DrillingEfficiency(rollbar=rollbar)
+    app = DrillingEfficiency()
     app.load(event)
     app.run_modules()
     app.save_state()
