@@ -1,17 +1,20 @@
 import json
-from typing import Union, Tuple
+from typing import List, Tuple, Union
+
 import numpy as np
+
 from worker.data.api import API
 from worker.data.enums import EventTypes
 
 
-def gather_wits_for_period(asset_id: int, start: int, end: int, limit: int = 1800) -> list:
+def gather_data_for_period(asset_id: int, start: int, end: int, limit: int = 1800, collection: str = "wits") -> list:
     """
     Get the wits data from API for an asset over an interval
     :param asset_id: asset id
     :param start: start timestamp
     :param end: end timestamp
     :param limit: count of the data
+    :param collection: any collection
     :return: a list of wits data
     """
     if start >= end:
@@ -20,7 +23,7 @@ def gather_wits_for_period(asset_id: int, start: int, end: int, limit: int = 180
     query = '{timestamp#gte#%s}AND{timestamp#lte#%s}' % (start, end)
     worker = API()
     wits_dataset = worker.get(
-        path="/v1/data/corva", collection='wits', asset_id=asset_id, sort="{timestamp: 1}", limit=limit, query=query
+        path="/v1/data/corva", collection=collection, asset_id=asset_id, sort="{timestamp: 1}", limit=limit, query=query
     ).data
 
     if not wits_dataset:
@@ -29,15 +32,16 @@ def gather_wits_for_period(asset_id: int, start: int, end: int, limit: int = 180
     return wits_dataset
 
 
-def get_one_wits_record(asset_id: int, timestamp_sort: int = -1) -> dict:
+def get_one_data_record(asset_id: int, timestamp_sort: int = -1, collection: str = "wits") -> dict:
     """
     Get the first or last wits record of a given asset
     :param asset_id:
     :param timestamp_sort:
+    :param collection:
     :return:
     """
     api_worker = API()
-    data = api_worker.get(path='/v1/data/corva/', collection='wits', asset_id=asset_id,
+    data = api_worker.get(path='/v1/data/corva/', collection=collection, asset_id=asset_id,
                           sort="{timestamp:%s}" % timestamp_sort, limit=1).data
     if not data:
         return {}
@@ -135,7 +139,7 @@ def none_to_nan(data):
     return data
 
 
-def get_data_by_path(data: dict, path: str, func=lambda x: x, default=None):
+def get_data_by_path(data: dict, path: str, func=lambda x: x, **kwargs):
     """
     To find the path to a key in a nested dictionary.
     Note that none of the keys should end up in a list
@@ -144,11 +148,15 @@ def get_data_by_path(data: dict, path: str, func=lambda x: x, default=None):
         'data.X.Y'
         'data.bit_depth'
     :param func: the type of the data (int, str, float, ...)
-    :param default: default value if the path not found
+    :param kwargs: pass default value in case the path not found;
+    note that None is an acceptable default
     :return:
     """
+    has_default = 'default' in kwargs
+    default = kwargs.pop('default', None)
+
     if not path:
-        if default is not None:
+        if has_default:
             return default
 
         raise KeyError("No key provided")
@@ -159,13 +167,16 @@ def get_data_by_path(data: dict, path: str, func=lambda x: x, default=None):
         current_key = keys.pop(0)
 
         if current_key not in data:
-            if default:
+            if has_default:
                 return default
 
             raise KeyError("{0} not found in path".format(current_key))
 
         data = data.get(current_key)
 
+    if data is None:
+        return None
+
     return func(data)
 
 
@@ -207,6 +218,20 @@ def merge_dicts(d1: dict, d2: dict) -> dict:
     return d
 
 
+def equal(obj1: object, obj2: object, params: List[str]) -> bool:
+    """
+    To check if two objects are equal by comparing the given parameters.
+    :param obj1:
+    :param obj2:
+    :param params:
+    :return:
+    """
+    if type(obj1) is not type(obj2):
+        return False
+
+    return all(getattr(obj1, param) == getattr(obj2, param) for param in params)
+
+
 def get_cleaned_event_and_type(event) -> Tuple[Union[list, dict], EventTypes]:
     """
     validate and flatten the events and organize the data into a desired format
@@ -233,21 +258,21 @@ def get_cleaned_event_and_type(event) -> Tuple[Union[list, dict], EventTypes]:
         if "task_id" in event:
             return event, EventTypes.TASK
 
-        raise TypeError(f"Missing task_id or asset_id keys in event")
+        raise TypeError("Missing task_id or asset_id keys in event")
 
     if not isinstance(event, list):
-        raise TypeError(f"Event is not a list or a dict")
+        raise TypeError("Event is not a list or a dict")
 
     first_event = event[0]
     if isinstance(first_event, list):
         if first_event[0] and "schedule_start" in first_event[0]:
             return event, EventTypes.SCHEDULER
 
-        raise Exception(f"Missing scheduler_start key in scheduler event")
+        raise Exception("Missing scheduler_start key in scheduler event")
 
     elif isinstance(first_event, dict):
         # new kafka stream format: list of json objects, each with metadata and records
         # event = [{"metadata": { ... }, "records": [ ... ]}, {"metadata": { ... }, "records": [ ... ]}]
         return event, EventTypes.STREAM
 
-    raise TypeError(f"Event is not either a scheduler or kafka consumer")
+    raise TypeError("Event is not either a scheduler or kafka consumer")
