@@ -22,12 +22,15 @@ if __name__ == '__main__':
 """
 
 import argparse
+import os
 from distutils.util import strtobool
+from typing import List
+
 from tqdm import tqdm
 
-from worker import constants
+import worker.framework.constants as constants
 from worker.data.operations import delete_collection_data_of_asset_id, get_one_data_record, gather_data_for_period
-from worker.framework.mixins import RedisMixin
+from worker.state.mixins import StateMixin
 from worker.test.utils import get_last_processed_timestamp, create_scheduler_events
 
 
@@ -43,11 +46,13 @@ def generate_parser():
     parser.add_argument("-i", "--timestep", "--step", type=int, required=False, default=60, help="trigger the lambda function once every step")
     parser.add_argument("-t", "--event_type", "--event", type=str, required=False, default="scheduler", help="type of event, scheduler or wits_stream")
     parser.add_argument("-d", "--to_delete", "--delete", type=strtobool, required=False, default=False, help="to delete the state and data")
+    parser.add_argument("-g", "--storage_type", "--storage", type=str, required=False, default="redis", help="type of state storage, redis or mongo")
     return parser
 
 
 class AppTestRun:
     def __init__(self, lambda_handler, collections, args=None):
+
         self.lambda_handler = lambda_handler
         self.collections = collections
 
@@ -62,24 +67,31 @@ class AppTestRun:
 
     def initialize(self, args):
         asset_id = args.asset_id
+
+        os.environ["LOGGING_ASSET_ID"] = str(asset_id)
+        os.environ["LOGGING_LEVEL"] = "off"
+
         start_timestamp = args.start_timestamp
         end_timestamp = args.end_timestamp
         step = args.timestep
         self.event_type = args.event_type
         to_delete = args.to_delete
 
-        app_redis = "corva/{0}.{1}".format(asset_id, constants.get("global.app-key"))
+        # Setup state storage type environment
+        state_storage_type = args.storage_type.lower()
+        os.environ["STATE_STORAGE_TYPE"] = state_storage_type
 
+        state_keys = construct_state_keys(constants, asset_id)
         if not start_timestamp:
             start_timestamp = get_one_data_record(asset_id, timestamp_sort=+1).get('timestamp')
         if not end_timestamp:
             end_timestamp = get_one_data_record(asset_id, timestamp_sort=-1).get('timestamp')
         if to_delete:
-            RedisMixin.delete_states(pattern=f"{app_redis}*")
+            delete_state_data_of_asset_id(asset_id, state_keys, state_storage_type=state_storage_type)
             delete_collection_data_of_asset_id(asset_id, self.collections)
-            print("Deleted relevant states and collections for this asset!")
+            print(f"Deleted relevant {state_storage_type} states and collections for this asset!")
 
-        start_timestamp = get_last_processed_timestamp(app_redis) or start_timestamp
+        start_timestamp = get_last_processed_timestamp(asset_id, state_keys[0], state_storage_type) or start_timestamp
         print(f"asset_id: {asset_id}, timestamp interval: [{start_timestamp}, {end_timestamp}]")
 
         events = create_scheduler_events(asset_id, start_timestamp, end_timestamp, step)
@@ -100,3 +112,39 @@ class AppTestRun:
                 e = [wits]
             self.lambda_handler(e, None)
             self.progress.set_description(schedule_time)
+
+        # Reset environment for other tests
+        del os.environ["STATE_STORAGE_TYPE"]
+
+
+def construct_state_keys(consts, asset_id: int) -> List[str]:
+    """
+    Get the constants dict of an app and construct the storage keys.
+    Note: the first key is the global app key.
+    :param consts: app constants module
+    :param asset_id: well asset id
+    :return: a list of storage keys
+    """
+    app_key = consts.get("global.app-key")
+    module_keys = list(consts.get(app_key).keys())
+    state_app = StateMixin()
+    global_state_key = state_app.get_formatted_state_key(asset_id, app_key)
+
+    module_state_keys = [
+        state_app.get_formatted_state_key(asset_id, app_key, module)
+        for module in module_keys
+    ]
+
+    return [global_state_key, *module_state_keys]
+
+
+def delete_state_data_of_asset_id(asset_id: int, state_keys: List[str], state_storage_type=None):
+    """
+    Delete the state from given storage type
+    :param asset_id:
+    :param state_keys:
+    :param state_storage_type:
+    :return:
+    """
+    state_app = StateMixin(state_storage_type)
+    state_app.delete_states(asset_id, state_keys)
